<?php

/* Replace the directory below with the directory that you wish to store received MMS messages in */
$upload_path = "c:\\upload\\";

/* By default, the script will return an HTTP 500 error if there are any internal processing errors,
    such as a problem creating a directory or file.  Returning an error in this way can signal the submitting
    application that there is a problem and that it may need to retry.  However, it can make it difficult
    to debug problems when testing submissions via a web form.  Set this variable to False to disable the 
    returning of an HTTP 500 error code.    */
$returnHttp500OnError = True;

/* Variables used by script */
$errorFlag = False;       /* Set to True if an error has occurred */
$dateString = date("YmdHis");  /* MMS images will be stored in a temporary directory name based upon current date/time */
$savedImageFile = False;   /* If an error occurs, or the message is text only, delete the temporary directory */

/* MMSFrom variable contains the sender phone number - REQUIRED */
if (!isset($_REQUEST['MMSFrom']) || !$_REQUEST['MMSFrom']) {
   echo "ERROR: MMSFrom variable (sender) is not set";
   $errorFlag = True;
}

/* MMSSubject variable contains the message subject - if not set, use default text */
if (!isset($_REQUEST['MMSSubject']) || !$_REQUEST['MMSSubject']) {
   $MMSSubject = "Multimedia Message";
}
else {
   $MMSSubject = $_REQUEST['MMSSubject'];
}


/* Validate that there is one or more HTTP file upload in the MMSFile[] array */
if (!$errorFlag) {
   $errorFlag = True; /* Default to returning an error, unless we find a valid HTTP file upload */
   if ($_FILES["MMSFile"] && is_array($_FILES["MMSFile"]) && count($_FILES["MMSFile"])) {
      foreach ($_FILES["MMSFile"]["error"] as $key => $error) {
         if ($error == UPLOAD_ERR_OK) {
            $errorFlag = False; /* reset error condition, found a valid HTTP file upload */
         }
      }
   }
   if ($errorFlag) {
      echo "ERROR:  Request does not include any uploaded files!";
   }
}

/* Build a directory for each user beneath the $upload_path, verify that we have rights to create a temporary file in this user directory */
if (!$errorFlag) {
   $user_path = $upload_path . $_REQUEST['MMSFrom'];
   if (!@file_exists ($user_path)) {
      @mkdir ($user_path);
   }
   $user_path = $user_path . "\\";
   $tmp_filename = $user_path . "temp.tmp";
   $tmp_handle = @fopen ($tmp_filename, "w+");
   if (!$tmp_handle) {
      if ($returnHttp500OnError) header("HTTP/1.0 500 Internal Error");
      echo "ERROR:  Cannot create files in upload directory " . $user_path;
      $errorFlag = True;
   }
   else {
      fclose ($tmp_handle);
      @unlink ($tmp_filename);
   }
}

/* Build a temporary directory beneath the user directory for storing image files associated with this MMS message */
if (!$errorFlag) {
   $image_path = $user_path . $dateString;
   if (!@file_exists ($image_path)) {
      @mkdir ($image_path);
   }
   $image_path = $image_path . "\\";
   $tmp_filename = $image_path . "temp.tmp";
   $tmp_handle = @fopen ($tmp_filename, "w+");
   if (!$tmp_handle) {
      if ($returnHttp500OnError) header("HTTP/1.0 500 Internal Error");
      echo "ERROR:  Cannot create files in upload directory " . $image_path;
      $errorFlag = True;
   }
   else {
      fclose ($tmp_handle);
      @unlink ($tmp_filename);
   }
}

if (!$errorFlag) {
   /* msglog.txt contains previous messages posted by this user in HTML format, without HTML headers.
      If this file exists, we copy it to msglog.tmp, so that we can create a new
      msglog.txt file with this new message at the top. */
   $msglogTxt = $user_path . "msglog.txt";
   $msglogTmp = $user_path . "msglog.tmp";
   if (@file_exists ($msglogTmp)) {
      @unlink ($msglogTmp);
   }
   if (@file_exists ($msglogTxt)) {
      if (!@copy ($msglogTxt, $msglogTmp)) {
         if ($returnHttp500OnError) header("HTTP/1.0 500 Internal Error");
         echo "ERROR:  Cannot create temporary file in upload directory " . $user_path;
         $errorFlag = True;
      }
   }
   if (!$errorFlag) {
      $msglogTxt_handle = @fopen ($msglogTxt, "w+");
      if (!$msglogTxt_handle) {
         if ($returnHttp500OnError) header("HTTP/1.0 500 Internal Error");
         echo "ERROR:  Cannot create temporary file in upload directory " . $user_path;
         $errorFlag = True;
      }
   }

   if (!$errorFlag) {
      /* This is where we take the MMS message content, and convert it to simple HTML */
      fwrite ($msglogTxt_handle, "<!-- Begin message block -->\r\n");
      fwrite ($msglogTxt_handle, "<h2>" . $MMSSubject . "</h2>\r\n");
      fwrite ($msglogTxt_handle, "<p><small>" . date("F j, Y, H:i") . "</small></p>\r\n");

      /* Repeat for each object/file within the MMS message */
      foreach ($_FILES["MMSFile"]["error"] as $key => $error) {
         if ($error == UPLOAD_ERR_OK) {
            $tmp_name = $_FILES["MMSFile"]["tmp_name"][$key];
            /* If the content is text, put it directly into the HTML */
            if (!strcmp (strtolower($_FILES["MMSFile"]["type"][$key]), "text/plain")) {
               fwrite ($msglogTxt_handle, "<p>" . file_get_contents ($tmp_name) . "</p>\r\n");
               echo "The file ".  basename( $_FILES["MMSFile"]["name"][$key]). " has been uploaded<br/>";
            }
            /* If the content is SMIL, ignore it */
            else if (!strcmp (strtolower($_FILES["MMSFile"]["type"][$key]), "application/smil")) {
               echo "The file ".  basename( $_FILES["MMSFile"]["name"][$key]). " has been skipped<br/>";
            }
            else {
               /* If content is an image, reference it with an img tag, otherwise include an a href */
               $new_name = $image_path . basename( $_FILES["MMSFile"]["name"][$key]); 
               if (@move_uploaded_file($tmp_name, $new_name)) {
                  $savedImageFile = True;
                  echo "The file ".  basename( $_FILES["MMSFile"]["name"][$key]). " has been uploaded<br/>";
                  if (!strncmp (strtolower($_FILES["MMSFile"]["type"][$key]), "image/", 6)) {
                     fwrite ($msglogTxt_handle, "<p><img src=\"" . $dateString . "\\" . basename($_FILES["MMSFile"]["name"][$key]) . "\"/></p>\r\n");
                  }
                  else if (!strncmp (strtolower($_FILES["MMSFile"]["type"][$key]), "video/", 6)) {
                     fwrite ($msglogTxt_handle, "<p>Video attachment:  <a href=\"" . $dateString . "\\" . basename($_FILES["MMSFile"]["name"][$key]) . "\">" . basename($_FILES["MMSFile"]["name"][$key]) .                                     "</a></p>\r\n");
                  }
                  else {
                     fwrite ($msglogTxt_handle, "<p>File attachment:  <a href=\"" . $dateString . "\\" . basename($_FILES["MMSFile"]["name"][$key]) . "\">" . basename($_FILES["MMSFile"]["name"][$key]) .                                     "</a></p>\r\n");
                  }
               }
               else {
                  echo "Error uploading file ".  basename( $_FILES["MMSFile"]["name"][$key]) . "<br/>";
               }
            }
         }
      }
      fwrite ($msglogTxt_handle, "<!-- End message block -->\r\n");

      /* If we saved previous message entries to msglog.tmp, we need to add them back to this file */

      if (@file_exists ($msglogTmp)) {
         fwrite ($msglogTxt_handle, file_get_contents ($msglogTmp));
         @unlink ($msglogTmp);
      }
      fclose ($msglogTxt_handle);
   }

   /* If we didn't save any images (message is text only), then delete the temporary directory */
   if (!$savedImageFile && $image_path) {
      @rmdir ($user_path . $dateString);
   }

}

/* Now we put the HTML footers in place, creating index.html in the user directory */

if (!$errorFlag) {
   $htmlFile = $user_path . "index.html";
   $htmlFile_handle = @fopen ($htmlFile, "w+");
   if (!$htmlFile_handle) {
      if ($returnHttp500OnError) header("HTTP/1.0 500 Internal Error");
      echo "ERROR:  Cannot create file in user upload directory " . $user_path;
      $errorFlag = True;
   }
   else {
      fwrite ($htmlFile_handle, "<html>\r\n<head>\r\n<title>MMS Message Log for " . $_REQUEST['MMSFrom'] . "</title>\r\n</head>\r\n<body>\r\n");
      fwrite ($htmlFile_handle, "<h1>MMS Message Log for " . $_REQUEST['MMSFrom'] . "</h1>\r\n");
      fwrite ($htmlFile_handle, file_get_contents ($user_path . "msglog.txt"));
      fwrite ($htmlFile_handle, "</body>\r\n</html>\r\n");
      fclose ($htmlFile_handle);
   }

}
